# Betterproto2 compiler

![](https://github.com/betterproto/python-betterproto2-compiler/actions/workflows/ci.yml/badge.svg)



## License

Copyright © 2019 Daniel G. Taylor

Copyright © 2024 The betterproto contributors
